@@ -4,5 +4,5 @@ use nxui::natives_and_messaging::*;
 
 fn main() {
     nxui::initialize();
-    MessageBox::new("日本語ｷﾀーーー！！ ", "日本語が使えるようになりました。", DIALOGSTYLE_QUESTION, BUTTONSTYLE_YESNO).show(Frame::default());
+    MessageBox::new("日本語ｷﾀーーー！！ ", "日本語が使えるようになりました。", DS_QUESTION, BS_YESNO).show(Frame::default());
 }
\ No newline at end of file
