@@ -16,22 +16,24 @@ type TSzwBuf   = [u16; SZW_SIZE];
 
 
 #[cfg(windows)]
-pub struct FileChooser<'a> {
+pub struct OpenFileDialog<'a> {
     /// Dialog Title
-    pub title: &'a str
+    pub title: &'a str,
+    pub style: winapi::shared::minwindef::DWORD
 }
 
 #[cfg(windows)]
-impl<'a> FileChooser<'a> {
-    pub fn new(title: &'a str) -> Self {
+impl<'a> OpenFileDialog<'a> {
+    pub fn new(title: &'a str,style: winapi::shared::minwindef::DWORD) -> Self {
         Self {
-            title
+            title,
+            style
         }
     }
 
     #[allow(non_snake_case)]
     pub fn show(&self) -> String {
-        use winapi::um::commdlg::{OPENFILENAMEW, OFN_HIDEREADONLY};
+        use winapi::um::commdlg::*;
         use winapi::um::commdlg::GetOpenFileNameW;
 
         const SZW_SIZE: usize = 512;
@@ -54,7 +56,7 @@ impl<'a> FileChooser<'a> {
             nMaxFileTitle:     0,                                 // DWORD,
             lpstrInitialDir:   null_mut(),                        // LPCWSTR,
             lpstrTitle:        szwTitle.as_ptr(),                 // LPCWSTR,
-            Flags:             OFN_HIDEREADONLY,                  // DWORD,
+            Flags:             self.style,                  // DWORD,
             nFileOffset:       0,                                 // WORD,
             nFileExtension:    0,                                 // WORD,
             lpstrDefExt:       null_mut(),                        // LPCWSTR,
@@ -66,14 +68,10 @@ impl<'a> FileChooser<'a> {
             FlagsEx:           0,                                 // DWORD,
         };
 
-        let mut result = "".to_string();
-
         match unsafe { GetOpenFileNameW(&mut dlgOpen) } {
-            0 => result = "Nothing is selected !".to_string(),
-            _ => result = szw_to_string( &szw_buf ).unwrap(),
-        };
-
-        result
+            0 => "Nothing is selected !".to_string(),
+            _ => szw_to_string( &szw_buf ).unwrap(),
+        }
     }
 }
 
@@ -96,12 +94,12 @@ fn str_to_szw(str_body: &str) -> Vec<u16> {
 }
 
 #[cfg(unix)]
-pub struct FileChooser<'a> {
+pub struct OpenFileDialog<'a> {
     pub title: &'a str
 }
 
 #[cfg(unix)]
-impl<'a> FileChooser<'a> {
+impl<'a> OpenFileDialog<'a> {
     pub fn new(title: &'a str) -> Self {
         Self {
             /// Dialog Title
@@ -134,4 +132,61 @@ impl<'a> FileChooser<'a> {
 
         file
     }
+}
+
+pub struct SaveFileDialog<'a> {
+    /// Dialog Title
+    pub title: &'a str,
+    pub style: winapi::shared::minwindef::DWORD
+}
+
+impl<'a> SaveFileDialog<'a> {
+    pub fn new(title: &'a str,style: winapi::shared::minwindef::DWORD) -> Self {
+        Self {
+            title,
+            style
+        }
+    }
+
+    #[allow(non_snake_case)]
+    pub fn show(&self) -> String {
+        use winapi::um::commdlg::*;
+
+        const SZW_SIZE: usize = 512;
+        type TSzwBuf   = [u16; SZW_SIZE];
+
+        let szwFilter = str_to_szw(" ");
+        let szwTitle  = str_to_szw(self.title);
+        let mut szw_buf: TSzwBuf = [0; SZW_SIZE];
+        let mut dlgOpen = OPENFILENAMEW {
+            lStructSize:       size_of::<OPENFILENAMEW>() as u32, //DWORD,
+            hwndOwner:         null_mut(),                        // HWND,
+            hInstance:         null_mut(),                        // HINSTANCE,
+            lpstrFilter:       szwFilter.as_ptr(),                // LPCWSTR,
+            lpstrCustomFilter: null_mut(),                        // LPWSTR,
+            nMaxCustFilter:    0,                                 // DWORD,
+            nFilterIndex:      0,                                 // DWORD,
+            lpstrFile:         szw_buf.as_mut_ptr(),              // LPWSTR,
+            nMaxFile:          szw_buf.len() as u32,              // DWORD,
+            lpstrFileTitle:    null_mut(),                        // LPWSTR,
+            nMaxFileTitle:     0,                                 // DWORD,
+            lpstrInitialDir:   null_mut(),                        // LPCWSTR,
+            lpstrTitle:        szwTitle.as_ptr(),                 // LPCWSTR,
+            Flags:             self.style,                  // DWORD,
+            nFileOffset:       0,                                 // WORD,
+            nFileExtension:    0,                                 // WORD,
+            lpstrDefExt:       null_mut(),                        // LPCWSTR,
+            lCustData:         0,                                 // LPARAM,
+            lpfnHook:          None,                              // LPOFNHOOKPROC,
+            lpTemplateName:    null_mut(),                        // LPCWSTR,
+            pvReserved:        null_mut(),                        // *mut c_void,
+            dwReserved:        0,                                 // DWORD,
+            FlagsEx:           0,                                 // DWORD,
+        };
+
+        match unsafe { GetSaveFileNameW(&mut dlgOpen) } {
+            0 => "Nothing is selected !".to_string(),
+            _ => szw_to_string( &szw_buf ).unwrap(),
+        }
+    }
 }
\ No newline at end of file
